# Changelog

## insiders Insiders

### 1.0.2 <small>May 25, 2024</small> { id="1.0.2" }

- Output complete skeleton for public project, not just README and workflow
- Use copier-uv template for my own projects

### 1.0.1 <small>November 23, 2023</small> { id="1.0.1" }

- Fix bug in commands (pop `help` flag)

### 1.0.0 <small>October 29, 2023</small> { id="1.0.0" }

- Release first Insiders version
